# progress-text

Python package for printing progress in text.

## Why not [tqdm](https://github.com/tqdm/tqdm)

[tqdm](https://github.com/tqdm/tqdm) is awesome, but I just want to print the progress to a log file by `nohup`.

## Install

```shell
pip3 install --upgrade progress-text
```

Or simply copy the source code.

## Usage

See [`example.py`](./example.py).

## To do

None
